-- -
-- #%L
-- %%
-- Copyright (C) 2005 - 2026 Kuali, Inc. - All Rights Reserved
-- %%
-- You may use and modify this code under the terms of the Kuali, Inc.
-- Pre-Release License Agreement. You may not distribute it.
-- 
-- You should have received a copy of the Kuali, Inc. Pre-Release License
-- Agreement with this file. If not, please write to license@kuali.co.
-- #L%
-- -

delete from S2S_OPPORTUNITY_CFDA where trim(CFDA_NUMBER) = '';
delete from EPS_PROP_CFDA where trim(CFDA_NUMBER) = '';
delete from PROPOSAL_CFDA where trim(CFDA_NUMBER) = '';
delete from AWARD_CFDA where trim(CFDA_NUMBER) = '';
